==> apache-camel-2.15.6-src.zip: apache-camel-2.15.6/examples/camel-example-splunk/src/main/java/org/apache/camel/example/splunk/SplunkPublishEventClient.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.example.splunk;

import org.apache.camel.CamelContext;
import org.apache.camel.ProducerTemplate;
import org.apache.camel.impl.DefaultCamelContext;
import org.apache.log4j.Logger;

public final class SplunkPublishEventClient {

    private static final Logger LOG = Logger.getLogger(SplunkPublishEventClient.class);

    private SplunkPublishEventClient() {
    }

    public static void main(String[] args) throws Exception {
        LOG.info("About to run splunk-camel integration...");

        CamelContext camelContext = new DefaultCamelContext();
        camelContext.addRoutes(new SplunkPublishEventRouteBuilder());
        ProducerTemplate eventProducer = camelContext.createProducerTemplate();
        camelContext.start();
        eventProducer.request("direct:start", new SplunkEventProcessor());

        LOG.info("Successfully published event to Splunk.");

        camelContext.stop();
    }
}

==> apache-camel-2.25.4-src.zip: apache-camel-2.25.4/examples/camel-example-splunk/src/main/java/org/apache/camel/example/splunk/SplunkPublishEventClient.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.example.splunk;

import org.apache.camel.CamelContext;
import org.apache.camel.ProducerTemplate;
import org.apache.camel.impl.DefaultCamelContext;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public final class SplunkPublishEventClient {

    private static final Logger LOG = LoggerFactory.getLogger(SplunkPublishEventClient.class);

    private SplunkPublishEventClient() {
    }

    public static void main(String[] args) throws Exception {
        LOG.info("About to run splunk-camel integration...");

        CamelContext camelContext = new DefaultCamelContext();
        camelContext.addRoutes(new SplunkPublishEventRouteBuilder());
        ProducerTemplate eventProducer = camelContext.createProducerTemplate();
        camelContext.start();
        eventProducer.request("direct:start", new SplunkEventProcessor());

        LOG.info("Successfully published event to Splunk.");

        camelContext.stop();
    }
}
